var indexSectionsWithContent =
{
  0: "_abcdefghijklmnopqrstuvwxyz~",
  1: "bcghimrtw",
  2: "abcdefghijklmnopqrstuvwxz",
  3: "_abcdefghijklmnopqrstuvwxyz~",
  4: "abcdefghiklmnoprstvwxy",
  5: "bcdefiprsvw",
  6: "abcdefhkmnoprstvwy",
  7: "abcdefghijklmnopqrstuw",
  8: "w",
  9: "_w",
  10: "abcdefghilmnoprstvwx",
  11: "abcdefghilmnoprstuwx"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "files",
  3: "functions",
  4: "variables",
  5: "typedefs",
  6: "enums",
  7: "enumvalues",
  8: "related",
  9: "defines",
  10: "groups",
  11: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Files",
  3: "Functions",
  4: "Variables",
  5: "Typedefs",
  6: "Enumerations",
  7: "Enumerator",
  8: "Friends",
  9: "Macros",
  10: "Modules",
  11: "Pages"
};

